
local AbsorbsMonitor = _G.AbsorbsMonitor;

local AceConfig = LibStub("AceConfig-3.0");
local AceConfigDialog = LibStub("AceConfigDialog-3.0");
local AceDB = LibStub("AceDB-3.0");


-- #################################################################################################


local function getProfileOption(info)
	return AbsorbsMonitor.db.profile[info.arg];
end

local function setProfileOption(info, value)
	AbsorbsMonitor.db.profile[info.arg] = value;
end


-- #################################################################################################


local defaults = {
	profile = {
		passive = false,
		silent = false,	
		zoneModifier = 1.3,
		zoneModifier_auto = true,
		lowValueTolerance = 50,
	},
};


-- #################################################################################################


local options = {
	type = 'group',
	get = getProfileOption,
	set = setProfileOption,
	
	args = {
		general = {
			type = "group",
			name = "General Options",
			cmdInline = true,
			order = -1,
			
			args = {
				options = {
					type = "execute",
					order = 1,
					name = "Options Window",
					desc = "Shows the Options Window",
					func = function()
						AbsorbsMonitor:ShowOptions();
					end,
					guiHidden = true,
				},			
				enabled = {
					type = "toggle",
					order = 2,
					name = "Enabled",
					desc = "Enable/Disable this addon",
					get = function() return AbsorbsMonitor:IsEnabled() end,
					set = function()
						if(AbsorbsMonitor:IsEnabled()) then
							AbsorbsMonitor:Disable();
						else
							AbsorbsMonitor:Enable()
						end
					end,
				},
				passive = {
					type = "toggle",
					order = 3,
					name = "Passive",
					desc = "Switches to passive mode, disabling all combat log parsing",
					arg = "passive",
					get = function() return AbsorbsMonitor.isPassive end,
					set = function()
						if(AbsorbsMonitor.isPassive) then
							AbsorbsMonitor:SetActive();
						else
							AbsorbsMonitor:SetPassive();
						end
					end,
				},
				silent = {
					type = "toggle",
					order = 4,
					name = "Silent",
					desc = "Switches to silent mode, disabling all addon communication",
					arg = "silent",
					get = function() return AbsorbsMonitor.isSilent end,
					set = function()
						if(AbsorbsMonitor.isSilent) then
							AbsorbsMonitor:SetSilent()
						else
							AbsorbsMonitor:SetVerbose()
						end
					end,
				},
				paramHeader = {
					type = "header",
					order = 5,
					name = "Parameters",
				},
				zonemod = {
					type = "range",
					order = 5,
					min = 0,
					max = 2.0,
					softMin = 0.9,
					softMax = 1.3,
					name = "Zone Modifier",
					desc = "Global factor on absorb effects like the ICC Buff or the PvP Penalty",
					arg = "zoneModifier",
				},
				zonemod_auto = {
					type = "toggle",
					order = 6,
					name = "Automatic Zone Modifier",
					desc = "Adjust the zone modifier automatically",
					arg = "zoneModifier_auto",				
					get = getProfileOption,
					set = function(...)
						setProfileOption(...);
						AbsorbsMonitor:OnZoneChangedNewArea();
					end
				},		
				lowcap = {
					type = "range",
					min = 0,
					max = 10000,
					softMin = 0,
					softMax = 250,					
					name = "Low Value Tolerance",
					desc = "Accepted tolerance for underestimating the absorb value",
					arg = "lowValueTolerance",					
				},						
			},
		},
	},
};


-- #################################################################################################


function AbsorbsMonitor:InitOptions()
	self.db = AceDB:New("AbsorbsMonitorDB", defaults);
	
	options.args.profile = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db);
	options.args.profile.order = -2;
	
	AceConfig:RegisterOptionsTable("AbsorbsMonitor", options, {"am", "absorbsmonitor"});
	
	self.optionsFrames = {}
	self.optionsFrames.general = AceConfigDialog:AddToBlizOptions("AbsorbsMonitor", nil, nil, "general");
	self.optionsFrames.profile = AceConfigDialog:AddToBlizOptions("AbsorbsMonitor", "Profiles", "AbsorbsMonitor", "profile");
end

function AbsorbsMonitor:ShowOptions()
	InterfaceOptionsFrame_OpenToCategory(self.optionsFrames.profile);
	InterfaceOptionsFrame_OpenToCategory(self.optionsFrames.general);
end
